@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2022 S[&]T, The Netherlands.
+ * Copyright (C) 2015-2023 S[&]T, The Netherlands.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -205,11 +205,10 @@ static int spherical_line_segment_from_polygon(harp_spherical_line *line, const
  */
 int harp_spherical_polygon_check(const harp_spherical_polygon *polygon)
 {
-    harp_spherical_line linei, linek;
     harp_vector3d vector;
     harp_spherical_point point;
+    const harp_spherical_point *p11, *p12, *p21, *p22;
     harp_euler_transformation se;
-    int8_t relationship;        /* Relationship between lines */
     int32_t i, k;
 
     /* Centre should not correspond to 0-vector */
@@ -224,19 +223,24 @@ int harp_spherical_polygon_check(const harp_spherical_polygon *polygon)
     /* Line segments should not cross each other */
     for (i = 0; i < polygon->numberofpoints; i++)
     {
-        /* Grab line segment from polygon */
-        spherical_line_segment_from_polygon(&linei, polygon, i);
-
         for (k = (i + 1); k < polygon->numberofpoints; k++)
         {
-            /* Grab line segment from polygon */
-            spherical_line_segment_from_polygon(&linek, polygon, k);
+            /* the first edge */
+            p11 = polygon->point + i;
+            p12 = polygon->point + i + 1;
 
-            /* Determine the relationship between two line segments */
-            relationship = harp_spherical_line_spherical_line_relationship(&linei, &linek);
+            /* the second edge */
+            p21 = polygon->point + k;
+            if (k == polygon->numberofpoints - 1)
+            {
+                p22 = polygon->point + 0;
+            }
+            else
+            {
+                p22 = polygon->point + k + 1;
+            }
 
-            /* Line segments should not cross each other, i.e. they should connect or avoid each other entirely */
-            if (!(relationship == HARP_GEOMETRY_LINE_CONNECTED || relationship == HARP_GEOMETRY_LINE_SEPARATE))
+            if (harp_spherical_line_intersects(p11, p12, p21, p22))
             {
                 harp_set_error(HARP_ERROR_INVALID_ARGUMENT, "invalid polygon (line segments overlap)");
                 return -1;
@@ -398,12 +402,6 @@ int harp_spherical_polygon_contains_point(const harp_spherical_polygon *polygon,
     harp_spherical_line sl;
     int result = 0;     /* false */
 
-    if (!spherical_polygon_bounds_contains_any_points(polygon, 1, point))
-    {
-        /* point is outside the lat/lon bounds of the polygon => return false */
-        return 0;
-    }
-
     /*--------------------------------
      * Check whether point is on edge.
      *--------------------------------*/
@@ -418,6 +416,12 @@ int harp_spherical_polygon_contains_point(const harp_spherical_polygon *polygon,
         }
     }
 
+    if (!spherical_polygon_bounds_contains_any_points(polygon, 1, point))
+    {
+        /* point is outside the lat/lon bounds of the polygon => return false */
+        return 0;
+    }
+
     /*-------------------------------------------
      * Check whether point is on a line segment.
      *------------------------------------------*/
@@ -626,7 +630,10 @@ int8_t harp_spherical_polygon_spherical_line_relationship(const harp_spherical_p
         pos = (int8_t)(1 << harp_spherical_line_spherical_line_relationship(&sl, line));
         if (pos == sl_eq)
         {
-            pos = sl_cd;        /* is contained */
+            /* if a line is equal to a line on the polygon then the line is
+             * separate. We can return immediately, since other lines will be
+             * either connected or separate. */
+            return HARP_GEOMETRY_LINE_POLY_SEPARATE;
         }
 
         if (pos == sl_ov)
@@ -664,7 +671,15 @@ int8_t harp_spherical_polygon_spherical_line_relationship(const harp_spherical_p
     {
         return HARP_GEOMETRY_LINE_POLY_CONTAINED;
     }
-    else if (!p1 && !p2 && ((res - sl_os - 1) < 0))
+    else if (!p1 && !p2 && res == sl_os)
+    {
+        return HARP_GEOMETRY_LINE_POLY_SEPARATE;
+    }
+    else if (p1 && !p2 && ((res - sl_os - sl_cn - 1) < 0))
+    {
+        return HARP_GEOMETRY_LINE_POLY_SEPARATE;
+    }
+    else if (!p1 && p2 && ((res - sl_os - sl_cn - 1) < 0))
     {
         return HARP_GEOMETRY_LINE_POLY_SEPARATE;
     }
@@ -680,7 +695,6 @@ int8_t harp_spherical_polygon_spherical_polygon_relationship(const harp_spherica
     harp_spherical_line sl;
     int8_t pos = 0, res = 0;
     const int8_t sp_os = (int8_t)(1 << HARP_GEOMETRY_LINE_POLY_SEPARATE);
-    const int8_t sp_ct = (int8_t)(1 << HARP_GEOMETRY_LINE_POLY_CONTAINED);
     const int8_t sp_ov = (int8_t)(1 << HARP_GEOMETRY_LINE_POLY_OVERLAP);
 
     if (!recheck)
@@ -699,13 +713,16 @@ int8_t harp_spherical_polygon_spherical_polygon_relationship(const harp_spherica
         pos = (int8_t)(1 << harp_spherical_polygon_spherical_line_relationship(polygon_a, &sl));
         if (pos == sp_ov)
         {
-            /* overlap */
+            /* If one edge is overlapping then the two polygons overlap. */
             return HARP_GEOMETRY_POLY_OVERLAP;
         }
 
         res |= pos;
     }
 
+    /* If all lines are separate, then either polygon_a is contained in
+     * polygon_b or the other way around. Therefore, we check the relation
+     * again, but the other way around. */
     if (res == sp_os)
     {
         if (!recheck)
@@ -715,17 +732,19 @@ int8_t harp_spherical_polygon_spherical_polygon_relationship(const harp_spherica
             {
                 return HARP_GEOMETRY_POLY_CONTAINED;
             }
-            assert(pos != HARP_GEOMETRY_LINE_POLY_OVERLAP);
+            assert(pos != HARP_GEOMETRY_POLY_OVERLAP);
         }
+        /* If the check has already been performed, then they are separate */
         return HARP_GEOMETRY_POLY_SEPARATE;
     }
-
-    if (res == sp_ct)
+    else
     {
+        /* If the edges are not all separate and there is no overlap, then
+         * polygon_a must contain polygon_b with at least one equal edge, which
+         * is regarded as separate.They cannot be overlapping, otherwise an
+         * edge would have crossed the polygon boundary. */
         return HARP_GEOMETRY_POLY_CONTAINS;
     }
-
-    return HARP_GEOMETRY_POLY_OVERLAP;
 }
 
 /* Determine whether two polygons overlap */
@@ -807,7 +826,15 @@ static int spherical_polygon_get_surface_area(const harp_spherical_polygon *poly
             c = M_PI_2 - latA;
             sinangle = sqrt(hav(a - c) + sin(a) * sin(c) * hav(lonC - lonA));
             HARP_CLAMP(sinangle, -1.0, 1.0);
-            b = 2 * asin(sinangle);
+            if (HARP_GEOMETRY_FPeq(sinangle, 0) && a > M_PI_2)
+            {
+                /* we need to special case the situation where we have the South Pole as a point */
+                b = M_PI;
+            }
+            else
+            {
+                b = 2 * asin(sinangle);
+            }
             s = 0.5 * (a + b + c);
             E = 4 * atan(sqrt(fabs(tan(s / 2) * tan((s - a) / 2) * tan((s - b) / 2) * tan((s - c) / 2))));
             if (lonC < lonA)
@@ -1271,6 +1298,7 @@ LIBHARP_API int harp_geometry_has_area_overlap(int num_vertices_a, double *latit
     if (harp_spherical_polygon_from_latitude_longitude_bounds(0, num_vertices_b, latitude_bounds_b, longitude_bounds_b,
                                                               1, &polygon_b) != 0)
     {
+        harp_spherical_polygon_delete(polygon_a);
         return -1;
     }
 
