@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2022 S[&]T, The Netherlands.
+ * Copyright (C) 2015-2023 S[&]T, The Netherlands.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -795,7 +795,7 @@ static int init_product_definition(harp_ingestion_module *module, gas_type gas,
     return 0;
 }
 
-int harp_ingestion_module_geoms_pandora_init()
+int harp_ingestion_module_geoms_pandora_init(void)
 {
     harp_ingestion_module *module;
     int i;
