@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2022 S[&]T, The Netherlands.
+ * Copyright (C) 2015-2023 S[&]T, The Netherlands.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -519,7 +519,7 @@ LIBHARP_API int harp_variable_convert_unit(harp_variable *variable, const char *
     return 0;
 }
 
-void harp_unit_done()
+void harp_unit_done(void)
 {
     unit_system_done();
 }
