@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2022 S[&]T, The Netherlands.
+ * Copyright (C) 2015-2023 S[&]T, The Netherlands.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -50,13 +50,13 @@ static int print_warning(const char *message, va_list ap)
     return result;
 }
 
-static void print_version()
+static void print_version(void)
 {
     printf("harpmerge version %s\n", libharp_version);
-    printf("Copyright (C) 2015-2022 S[&]T, The Netherlands.\n\n");
+    printf("Copyright (C) 2015-2023 S[&]T, The Netherlands.\n\n");
 }
 
-static void print_help()
+static void print_help(void)
 {
     printf("Usage:\n");
     printf("    harpmerge [options] <file|dir> [<file|dir> ...] <output product file>\n");
